# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from ..accessibility.x_accessible_image import XAccessibleImage as XAccessibleImage_6bc11099
from .accessible_shape import AccessibleShape as AccessibleShape_fdd20dd3

class AccessibleGraphicShape(AccessibleShape_fdd20dd3, XAccessibleImage_6bc11099):
    """
    Service Class

    The AccessibleGraphicShape service is implemented by the graphic object shapes shapes com.sun.star.drawing.GraphicObjectShape and com.sun.star.presentation.GraphicObjectShape.
    
    It differs from the included AccessibleShape \"base\" service by the additional support of the com.sun.star.accessibility.XAccessibleImage interface.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API AccessibleGraphicShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1AccessibleGraphicShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.AccessibleGraphicShape'
    __ooo_type_name__: str = 'service'


__all__ = ['AccessibleGraphicShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class ArrayWrapper(object):
    """
    Struct Class

    Allows a UNO sequence that is passed between different language boundaries to indicate it prefers to be represented as a multidimensional array with 0 or 1 based indices.
    
    UNO does not natively represent Multi-Dimensional arrays, instead a sequence can have elements that are themselves sequences (an array of arrays ).
    
    Some languages ( example BASIC ) can natively represent both Multi-Dimensional arrays and array of arrays. Those languages could represent a sequence of sequences as either a Multi-Dimensional array or array of arrays. This structure allows a preference for a Multi-Dimensional array representation to be specified.

    See Also:
        `API ArrayWrapper <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1script_1_1ArrayWrapper.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.ArrayWrapper'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.script.ArrayWrapper'
    """Literal Constant ``com.sun.star.script.ArrayWrapper``"""

    def __init__(self, IsZeroIndex: typing.Optional[bool] = False, Array: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            IsZeroIndex (bool, optional): IsZeroIndex value.
            Array (object, optional): Array value.
        """
        super().__init__()

        if isinstance(IsZeroIndex, ArrayWrapper):
            oth: ArrayWrapper = IsZeroIndex
            self.IsZeroIndex = oth.IsZeroIndex
            self.Array = oth.Array
            return

        kargs = {
            "IsZeroIndex": IsZeroIndex,
            "Array": Array,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._is_zero_index = kwargs["IsZeroIndex"]
        self._array = kwargs["Array"]


    @property
    def IsZeroIndex(self) -> bool:
        """
        Indicates whether the Array should be have 1 or 0 based indexing.
        """
        return self._is_zero_index

    @IsZeroIndex.setter
    def IsZeroIndex(self, value: bool) -> None:
        self._is_zero_index = value

    @property
    def Array(self) -> object:
        """
        Contains the Array to be passed.
        
        Multi-dimensional arrays can only be represented as a sequence where the elements of the sequence are themselves sequences. N-Levels of indirection are possible, where N is the number of dimensions. Note: its perfectly legal to use this structure with a single dimensioned array just to indicate the array indexing.
        """
        return self._array

    @Array.setter
    def Array(self, value: object) -> None:
        self._array = value


__all__ = ['ArrayWrapper']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from abc import abstractmethod
from .x_universal_content_broker import XUniversalContentBroker as XUniversalContentBroker_38ce0f93

class UniversalContentBroker(XUniversalContentBroker_38ce0f93):
    """
    Service Class

    is a one-instance service that provides access to a set of Contents via ContentProviders.
    
    Traditionally, this service implements com.sun.star.lang.XInitialization and needed to be instantiated once with two arguments via com.sun.star.lang.XMultiComponentFactory.createInstanceWithArgumentsAndContext() for configuration before it could be obtained via plain com.sun.star.lang.XMultiComponentFactory.createInstanceWithContext().
    
    However, the only pair of initialization arguments used in practice is \"Local\"/\"Office\", so this service is simplified now to automatically configure itself with that argument pair upon first instantiation.
    
    (For backwards compatibility, the service implementation still supports com.sun.star.lang.XInitialization and can still explicitly be initialized via com.sun.star.lang.XMultiComponentFactory.createInstanceWithArgumentsAndContext() with two arguments of type string. These strings are used as a pair of keys to retrieve a set of content provider descriptions from the configuration management (stored at org.openoffice.ucb.Configuration.ContentProviders.key1.SecondaryKeys.key2.ProviderData within the configuration management's hierarchy). The retrieved descriptions are in turn used to register the corresponding content provider services at the broker.)

    See Also:
        `API UniversalContentBroker <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1UniversalContentBroker.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.UniversalContentBroker'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self) -> None:
        """
        The (default) constructor.
        
        (This default constructor is only mentioned explicitly for technical reasons, so that its implementation calls the service implementation's com.sun.star.lang.XInitialization.initialize().)
        """
        ...

__all__ = ['UniversalContentBroker']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class MeasureUnit(metaclass=UnoConstMeta, type_name="com.sun.star.util.MeasureUnit", name_space="com.sun.star.util"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.util.MeasureUnit``"""
        pass

    class MeasureUnitEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.util.MeasureUnit", name_space="com.sun.star.util"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.util.MeasureUnit`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.util import MeasureUnit as MeasureUnit
    else:
        # keep document generators happy
        from ...lo.util.measure_unit import MeasureUnit as MeasureUnit

    class MeasureUnitEnum(IntEnum):
        """
        Enum of Const Class MeasureUnit

        These constants are used to specify a measure.
        
        A component using these constants may not support all units.
        """
        MM_100TH = MeasureUnit.MM_100TH
        """
        all measures for this component are in 100th millimeter
        """
        MM_10TH = MeasureUnit.MM_10TH
        """
        all measures for this component are in 10th millimeter
        """
        MM = MeasureUnit.MM
        """
        all measures for this component are in millimeter
        """
        CM = MeasureUnit.CM
        """
        all measures for this component are in centimeters
        """
        INCH_1000TH = MeasureUnit.INCH_1000TH
        """
        all measures for this component are in 1000th inch
        """
        INCH_100TH = MeasureUnit.INCH_100TH
        """
        all measures for this component are in 100th inch
        """
        INCH_10TH = MeasureUnit.INCH_10TH
        """
        all measures for this component are in 10th inch
        """
        INCH = MeasureUnit.INCH
        """
        all measures for this component are in inch
        """
        POINT = MeasureUnit.POINT
        """
        all measures for this component are in points
        """
        TWIP = MeasureUnit.TWIP
        """
        all measures for this component are in twips
        """
        M = MeasureUnit.M
        """
        all measures for this component are in meters
        """
        KM = MeasureUnit.KM
        """
        all measures for this component are in kilometers
        """
        PICA = MeasureUnit.PICA
        """
        all measures for this component are in pica
        """
        FOOT = MeasureUnit.FOOT
        """
        all measures for this component are in foot
        """
        MILE = MeasureUnit.MILE
        """
        all measures for this component are in miles
        """
        PERCENT = MeasureUnit.PERCENT
        """
        all measures for this component are in percentage
        """
        PIXEL = MeasureUnit.PIXEL
        """
        all measures for this component are in pixel
        """
        APPFONT = MeasureUnit.APPFONT
        """
        all measures for this component are in APPFONT
        """
        SYSFONT = MeasureUnit.SYSFONT
        """
        all measures for this component are in SYSFONT
        """

__all__ = ['MeasureUnit', 'MeasureUnitEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .tab_align import TabAlign as TabAlign_8fc90a3b


class TabStop(object):
    """
    Struct Class

    This structure is used to specify a single tabulator stop.

    See Also:
        `API TabStop <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1style_1_1TabStop.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.TabStop'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.style.TabStop'
    """Literal Constant ``com.sun.star.style.TabStop``"""

    def __init__(self, Position: typing.Optional[int] = 0, Alignment: typing.Optional[TabAlign_8fc90a3b] = TabAlign_8fc90a3b.LEFT, DecimalChar: typing.Optional[str] = '\u0000', FillChar: typing.Optional[str] = '\u0000') -> None:
        """
        Constructor

        Arguments:
            Position (int, optional): Position value.
            Alignment (TabAlign, optional): Alignment value.
            DecimalChar (str, optional): DecimalChar value.
            FillChar (str, optional): FillChar value.
        """
        super().__init__()

        if isinstance(Position, TabStop):
            oth: TabStop = Position
            self.Position = oth.Position
            self.Alignment = oth.Alignment
            self.DecimalChar = oth.DecimalChar
            self.FillChar = oth.FillChar
            return

        kargs = {
            "Position": Position,
            "Alignment": Alignment,
            "DecimalChar": DecimalChar,
            "FillChar": FillChar,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._position = kwargs["Position"]
        self._alignment = kwargs["Alignment"]
        self._decimal_char = kwargs["DecimalChar"]
        self._fill_char = kwargs["FillChar"]


    @property
    def Position(self) -> int:
        """
        This field specifies the position of the tabulator in relation to the left border.
        """
        return self._position

    @Position.setter
    def Position(self, value: int) -> None:
        self._position = value

    @property
    def Alignment(self) -> TabAlign_8fc90a3b:
        """
        This field specifies the alignment of the text range before the tabulator.
        """
        return self._alignment

    @Alignment.setter
    def Alignment(self, value: TabAlign_8fc90a3b) -> None:
        self._alignment = value

    @property
    def DecimalChar(self) -> str:
        """
        This field specifies which delimiter is used for the decimal.
        """
        return self._decimal_char

    @DecimalChar.setter
    def DecimalChar(self, value: str) -> None:
        self._decimal_char = value

    @property
    def FillChar(self) -> str:
        """
        This field specifies the character that is used to fill up the space between the text in the text range and the tabulators.
        """
        return self._fill_char

    @FillChar.setter
    def FillChar(self, value: str) -> None:
        self._fill_char = value


__all__ = ['TabStop']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..awt.rectangle import Rectangle as Rectangle_84b109e9

class XStatusbarItem(ABC):
    """
    Represents an item in a status bar.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API XStatusbarItem <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XStatusbarItem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XStatusbarItem'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XStatusbarItem'

    @abstractmethod
    def repaint(self) -> None:
        """
        forces repainting the item onto the status bar device
        """
        ...
    @abstractproperty
    def AccessibleName(self) -> str:
        """
        the accessible name of the status bar item
        """
        ...

    @abstractproperty
    def Command(self) -> str:
        """
        the command of the status bar item
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        the help text of the status bar item when extended help tips are on
        """
        ...

    @abstractproperty
    def ItemId(self) -> int:
        """
        the unique ID of the control within the status bar
        """
        ...

    @abstractproperty
    def ItemRect(self) -> Rectangle_84b109e9:
        """
        the rectangle on the status bar device onto which the item is drawn
        """
        ...

    @abstractproperty
    def Offset(self) -> int:
        """
        the offset between this status bar item and the following
        """
        ...

    @abstractproperty
    def QuickHelpText(self) -> str:
        """
        the help text of the status bar item when help tips are on
        """
        ...

    @abstractproperty
    def Style(self) -> int:
        """
        the style of the status bar item
        
        The following values apply for a status bar item:
        
        **since**
        
            LibreOffice 6.1)
        """
        ...

    @abstractproperty
    def Text(self) -> str:
        """
        the text of status bar item
        """
        ...

    @abstractproperty
    def Visible(self) -> bool:
        """
        whether the item is visible or not
        """
        ...

    @abstractproperty
    def Width(self) -> int:
        """
        the width of the status bar item
        """
        ...


__all__ = ['XStatusbarItem']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from .line_dash import LineDash as LineDash_a54e0afc
    from .poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords_7ec5114b
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.drawing.LineCap import LineCapProto  # type: ignore
    from com.sun.star.drawing.LineJoint import LineJointProto  # type: ignore
    from com.sun.star.drawing.LineStyle import LineStyleProto  # type: ignore

class LineProperties(ABC):
    """
    Service Class

    This is a set of properties to describe the style for rendering a Line.
    
    The properties for line ends and line starts are only supported by shapes with open line ends.

    See Also:
        `API LineProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1LineProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.LineProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def LineCap(self) -> LineCapProto:
        """
        This property defines the rendering of ends of thick lines.
        """
        ...

    @abstractproperty
    def LineColor(self) -> Color_68e908c5:
        """
        This property contains the line color.
        """
        ...

    @abstractproperty
    def LineDash(self) -> LineDash_a54e0afc:
        """
        This property contains the dash of the line.
        """
        ...

    @abstractproperty
    def LineDashName(self) -> str:
        """
        This property contains the name of the dash of the line.
        """
        ...

    @abstractproperty
    def LineEnd(self) -> PolyPolygonBezierCoords_7ec5114b:
        """
        This property contains the line end in the form of a poly polygon Bezier.
        """
        ...

    @abstractproperty
    def LineEndCenter(self) -> bool:
        """
        If this property is TRUE, the line will end in the center of the polygon.
        """
        ...

    @abstractproperty
    def LineEndName(self) -> str:
        """
        This property contains the name of the line end poly polygon Bezier.
        
        If this string is empty, no line end polygon is rendered.
        """
        ...

    @abstractproperty
    def LineEndWidth(self) -> int:
        """
        This property contains the width of the line end polygon.
        """
        ...

    @abstractproperty
    def LineJoint(self) -> LineJointProto:
        """
        This property defines the rendering of joints between thick lines.
        """
        ...

    @abstractproperty
    def LineStart(self) -> PolyPolygonBezierCoords_7ec5114b:
        """
        This property contains the line start in the form of a poly polygon Bezier.
        """
        ...

    @abstractproperty
    def LineStartCenter(self) -> bool:
        """
        If this property is TRUE, the line will start from the center of the polygon.
        """
        ...

    @abstractproperty
    def LineStartName(self) -> str:
        """
        This property contains the name of the line start poly polygon Bezier.
        
        If this string is empty, no line start polygon is rendered.
        """
        ...

    @abstractproperty
    def LineStartWidth(self) -> int:
        """
        This property contains the width of the line start polygon.
        """
        ...

    @abstractproperty
    def LineStyle(self) -> LineStyleProto:
        """
        This property contains the type of the line.
        """
        ...

    @abstractproperty
    def LineTransparence(self) -> int:
        """
        This property contains the extent of transparency.
        """
        ...

    @abstractproperty
    def LineWidth(self) -> int:
        """
        This property contains the width of the line in 1/100th mm.
        """
        ...


__all__ = ['LineProperties']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed


class EmbedMisc(object):
    """
    Const Class

    The constant set contains flags describing miscellaneous characteristics of embedded objects.
    
    The constant values can be combined with \"or\" operation. The first 32 bits are reserved for MS values, they are added because this API is going to be used to embed MS OLE objects into OOo documents, so there should be a possibility to transfer all the possible MS flags to container. In case own specific values should be added those bits can not be used.

    See Also:
        `API EmbedMisc <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1embed_1_1EmbedMisc.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.EmbedMisc'
    __ooo_type_name__: str = 'const'

    MS_EMBED_RECOMPOSEONRESIZE = 1
    """
    means that the object wish to regenerate view representation if it's view in the container is resized.
    """
    MS_EMBED_ONLYICONIC = 2
    """
    The object has no view representation except icon.
    """
    MS_EMBED_INSERTNOTREPLACE = 4
    """
    If the object is generated from a selection, the selection should not be removed, the object should be inserted beside the selection.
    """
    MS_EMBED_STATIC = 8
    """
    The object is a static object that contains only representation.
    """
    MS_EMBED_CANTLINKINSIDE = 16
    MS_EMBED_CANLINKBYOLE1 = 32
    MS_EMBED_ISLINKOBJECT = 64
    MS_EMBED_INSIDEOUT = 128
    MS_EMBED_ACTIVATEWHENVISIBLE = 256
    MS_EMBED_RENDERINGISDEVICEINDEPENDENT = 512
    MS_EMBED_INVISIBLEATRUNTIME = 1024
    MS_EMBED_ALWAYSRUN = 2048
    MS_EMBED_ACTSLIKEBUTTON = 4096
    MS_EMBED_ACTSLIKELABEL = 8192
    MS_EMBED_NOUIACTIVATE = 16384
    MS_EMBED_ALIGNABLE = 32768
    MS_EMBED_SIMPLEFRAME = 65536
    MS_EMBED_SETCLIENTSITEFIRST = 131072
    MS_EMBED_IMEMODE = 262144
    MS_EMBED_IGNOREACTIVATEWHENVISIBLE = 524288
    MS_EMBED_WANTSTOMENUMERGE = 1048576
    MS_EMBED_SUPPORTSMULTILEVELUNDO = 2097152
    EMBED_ACTIVATEIMMEDIATELY = 4294967296
    EMBED_NEVERRESIZE = 8589934592
    EMBED_NEEDSSIZEONLOAD = 17179869184
    """
    The object needs the size to be provided from the container after it is loaded to function in optimal way.
    """

__all__ = ['EmbedMisc']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.tab
from __future__ import annotations
from abc import abstractproperty, ABC

class XTabPageModel(ABC):
    """
    specifies an XTabPageModel interface.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XTabPageModel <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1tab_1_1XTabPageModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.tab'
    __ooo_full_ns__: str = 'com.sun.star.awt.tab.XTabPageModel'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.tab.XTabPageModel'

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether a tab page is enabled or disabled.
        """
        ...

    @abstractproperty
    def ImageURL(self) -> str:
        """
        specifies a URL that references a graphic that should be displayed in the tab bar.
        """
        ...

    @abstractproperty
    def TabPageID(self) -> int:
        """
        ID for tab page.
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        specifies the text that is displayed in the tab bar of the tab page.
        """
        ...

    @abstractproperty
    def ToolTip(self) -> str:
        """
        specifies a tooltip text that should be displayed in the tab bar.
        """
        ...


__all__ = ['XTabPageModel']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.awt.accessible_button import AccessibleButton as AccessibleButton
with suppress(ImportError):
    from ...dyn.awt.accessible_check_box import AccessibleCheckBox as AccessibleCheckBox
with suppress(ImportError):
    from ...dyn.awt.accessible_combo_box import AccessibleComboBox as AccessibleComboBox
with suppress(ImportError):
    from ...dyn.awt.accessible_drop_down_combo_box import AccessibleDropDownComboBox as AccessibleDropDownComboBox
with suppress(ImportError):
    from ...dyn.awt.accessible_drop_down_list_box import AccessibleDropDownListBox as AccessibleDropDownListBox
with suppress(ImportError):
    from ...dyn.awt.accessible_edit import AccessibleEdit as AccessibleEdit
with suppress(ImportError):
    from ...dyn.awt.accessible_fixed_text import AccessibleFixedText as AccessibleFixedText
with suppress(ImportError):
    from ...dyn.awt.accessible_icon_choice_control import AccessibleIconChoiceControl as AccessibleIconChoiceControl
with suppress(ImportError):
    from ...dyn.awt.accessible_icon_choice_control_entry import AccessibleIconChoiceControlEntry as AccessibleIconChoiceControlEntry
with suppress(ImportError):
    from ...dyn.awt.accessible_list import AccessibleList as AccessibleList
with suppress(ImportError):
    from ...dyn.awt.accessible_list_box import AccessibleListBox as AccessibleListBox
with suppress(ImportError):
    from ...dyn.awt.accessible_list_box_list import AccessibleListBoxList as AccessibleListBoxList
with suppress(ImportError):
    from ...dyn.awt.accessible_list_item import AccessibleListItem as AccessibleListItem
with suppress(ImportError):
    from ...dyn.awt.accessible_menu import AccessibleMenu as AccessibleMenu
with suppress(ImportError):
    from ...dyn.awt.accessible_menu_bar import AccessibleMenuBar as AccessibleMenuBar
with suppress(ImportError):
    from ...dyn.awt.accessible_menu_item import AccessibleMenuItem as AccessibleMenuItem
with suppress(ImportError):
    from ...dyn.awt.accessible_menu_separator import AccessibleMenuSeparator as AccessibleMenuSeparator
with suppress(ImportError):
    from ...dyn.awt.accessible_popup_menu import AccessiblePopupMenu as AccessiblePopupMenu
with suppress(ImportError):
    from ...dyn.awt.accessible_radio_button import AccessibleRadioButton as AccessibleRadioButton
with suppress(ImportError):
    from ...dyn.awt.accessible_scroll_bar import AccessibleScrollBar as AccessibleScrollBar
with suppress(ImportError):
    from ...dyn.awt.accessible_status_bar import AccessibleStatusBar as AccessibleStatusBar
with suppress(ImportError):
    from ...dyn.awt.accessible_status_bar_item import AccessibleStatusBarItem as AccessibleStatusBarItem
with suppress(ImportError):
    from ...dyn.awt.accessible_tab_bar import AccessibleTabBar as AccessibleTabBar
with suppress(ImportError):
    from ...dyn.awt.accessible_tab_bar_page import AccessibleTabBarPage as AccessibleTabBarPage
with suppress(ImportError):
    from ...dyn.awt.accessible_tab_bar_page_list import AccessibleTabBarPageList as AccessibleTabBarPageList
with suppress(ImportError):
    from ...dyn.awt.accessible_tab_control import AccessibleTabControl as AccessibleTabControl
with suppress(ImportError):
    from ...dyn.awt.accessible_tab_page import AccessibleTabPage as AccessibleTabPage
with suppress(ImportError):
    from ...dyn.awt.accessible_text_field import AccessibleTextField as AccessibleTextField
with suppress(ImportError):
    from ...dyn.awt.accessible_tool_box import AccessibleToolBox as AccessibleToolBox
with suppress(ImportError):
    from ...dyn.awt.accessible_tool_box_item import AccessibleToolBoxItem as AccessibleToolBoxItem
with suppress(ImportError):
    from ...dyn.awt.accessible_tree_list_box import AccessibleTreeListBox as AccessibleTreeListBox
with suppress(ImportError):
    from ...dyn.awt.accessible_tree_list_box_entry import AccessibleTreeListBoxEntry as AccessibleTreeListBoxEntry
with suppress(ImportError):
    from ...dyn.awt.accessible_window import AccessibleWindow as AccessibleWindow
with suppress(ImportError):
    from ...dyn.awt.action_event import ActionEvent as ActionEvent
with suppress(ImportError):
    from ...dyn.awt.adjustment_event import AdjustmentEvent as AdjustmentEvent
with suppress(ImportError):
    from ...dyn.awt.adjustment_type import AdjustmentType as AdjustmentType
with suppress(ImportError):
    from ...dyn.awt.animated_images_control import AnimatedImagesControl as AnimatedImagesControl
with suppress(ImportError):
    from ...dyn.awt.animated_images_control_model import AnimatedImagesControlModel as AnimatedImagesControlModel
with suppress(ImportError):
    from ...dyn.awt.async_callback import AsyncCallback as AsyncCallback
with suppress(ImportError):
    from ...dyn.awt.char_set import CharSet as CharSet
with suppress(ImportError):
    from ...dyn.awt.char_set import CharSetEnum as CharSetEnum
with suppress(ImportError):
    from ...dyn.awt.command import Command as Command
with suppress(ImportError):
    from ...dyn.awt.command import CommandEnum as CommandEnum
with suppress(ImportError):
    from ...dyn.awt.container_window_provider import ContainerWindowProvider as ContainerWindowProvider
with suppress(ImportError):
    from ...dyn.awt.device_capability import DeviceCapability as DeviceCapability
with suppress(ImportError):
    from ...dyn.awt.device_capability import DeviceCapabilityEnum as DeviceCapabilityEnum
with suppress(ImportError):
    from ...dyn.awt.device_info import DeviceInfo as DeviceInfo
with suppress(ImportError):
    from ...dyn.awt.dialog_provider import DialogProvider as DialogProvider
with suppress(ImportError):
    from ...dyn.awt.dialog_provider2 import DialogProvider2 as DialogProvider2
with suppress(ImportError):
    from ...dyn.awt.docking_data import DockingData as DockingData
with suppress(ImportError):
    from ...dyn.awt.docking_event import DockingEvent as DockingEvent
with suppress(ImportError):
    from ...dyn.awt.end_docking_event import EndDockingEvent as EndDockingEvent
with suppress(ImportError):
    from ...dyn.awt.end_popup_mode_event import EndPopupModeEvent as EndPopupModeEvent
with suppress(ImportError):
    from ...dyn.awt.enhanced_mouse_event import EnhancedMouseEvent as EnhancedMouseEvent
with suppress(ImportError):
    from ...dyn.awt.field_unit import FieldUnit as FieldUnit
with suppress(ImportError):
    from ...dyn.awt.field_unit import FieldUnitEnum as FieldUnitEnum
with suppress(ImportError):
    from ...dyn.awt.focus_change_reason import FocusChangeReason as FocusChangeReason
with suppress(ImportError):
    from ...dyn.awt.focus_change_reason import FocusChangeReasonEnum as FocusChangeReasonEnum
with suppress(ImportError):
    from ...dyn.awt.focus_event import FocusEvent as FocusEvent
with suppress(ImportError):
    from ...dyn.awt.font_descriptor import FontDescriptor as FontDescriptor
with suppress(ImportError):
    from ...dyn.awt.font_emphasis_mark import FontEmphasisMark as FontEmphasisMark
with suppress(ImportError):
    from ...dyn.awt.font_emphasis_mark import FontEmphasisMarkEnum as FontEmphasisMarkEnum
with suppress(ImportError):
    from ...dyn.awt.font_family import FontFamily as FontFamily
with suppress(ImportError):
    from ...dyn.awt.font_family import FontFamilyEnum as FontFamilyEnum
with suppress(ImportError):
    from ...dyn.awt.font_pitch import FontPitch as FontPitch
with suppress(ImportError):
    from ...dyn.awt.font_pitch import FontPitchEnum as FontPitchEnum
with suppress(ImportError):
    from ...dyn.awt.font_relief import FontRelief as FontRelief
with suppress(ImportError):
    from ...dyn.awt.font_relief import FontReliefEnum as FontReliefEnum
with suppress(ImportError):
    from ...dyn.awt.font_slant import FontSlant as FontSlant
with suppress(ImportError):
    from ...dyn.awt.font_strikeout import FontStrikeout as FontStrikeout
with suppress(ImportError):
    from ...dyn.awt.font_strikeout import FontStrikeoutEnum as FontStrikeoutEnum
with suppress(ImportError):
    from ...dyn.awt.font_type import FontType as FontType
with suppress(ImportError):
    from ...dyn.awt.font_type import FontTypeEnum as FontTypeEnum
with suppress(ImportError):
    from ...dyn.awt.font_underline import FontUnderline as FontUnderline
with suppress(ImportError):
    from ...dyn.awt.font_underline import FontUnderlineEnum as FontUnderlineEnum
with suppress(ImportError):
    from ...dyn.awt.font_weight import FontWeight as FontWeight
with suppress(ImportError):
    from ...dyn.awt.font_weight import FontWeightEnum as FontWeightEnum
with suppress(ImportError):
    from ...dyn.awt.font_width import FontWidth as FontWidth
with suppress(ImportError):
    from ...dyn.awt.font_width import FontWidthEnum as FontWidthEnum
with suppress(ImportError):
    from ...dyn.awt.gradient import Gradient as Gradient
with suppress(ImportError):
    from ...dyn.awt.gradient_style import GradientStyle as GradientStyle
with suppress(ImportError):
    from ...dyn.awt.image_align import ImageAlign as ImageAlign
with suppress(ImportError):
    from ...dyn.awt.image_align import ImageAlignEnum as ImageAlignEnum
with suppress(ImportError):
    from ...dyn.awt.image_draw_mode import ImageDrawMode as ImageDrawMode
with suppress(ImportError):
    from ...dyn.awt.image_draw_mode import ImageDrawModeEnum as ImageDrawModeEnum
with suppress(ImportError):
    from ...dyn.awt.image_position import ImagePosition as ImagePosition
with suppress(ImportError):
    from ...dyn.awt.image_position import ImagePositionEnum as ImagePositionEnum
with suppress(ImportError):
    from ...dyn.awt.image_scale_mode import ImageScaleMode as ImageScaleMode
with suppress(ImportError):
    from ...dyn.awt.image_scale_mode import ImageScaleModeEnum as ImageScaleModeEnum
with suppress(ImportError):
    from ...dyn.awt.image_status import ImageStatus as ImageStatus
with suppress(ImportError):
    from ...dyn.awt.image_status import ImageStatusEnum as ImageStatusEnum
with suppress(ImportError):
    from ...dyn.awt.input_event import InputEvent as InputEvent
with suppress(ImportError):
    from ...dyn.awt.invalidate_style import InvalidateStyle as InvalidateStyle
with suppress(ImportError):
    from ...dyn.awt.invalidate_style import InvalidateStyleEnum as InvalidateStyleEnum
with suppress(ImportError):
    from ...dyn.awt.item_event import ItemEvent as ItemEvent
with suppress(ImportError):
    from ...dyn.awt.item_list_event import ItemListEvent as ItemListEvent
with suppress(ImportError):
    from ...dyn.awt.key import Key as Key
with suppress(ImportError):
    from ...dyn.awt.key import KeyEnum as KeyEnum
with suppress(ImportError):
    from ...dyn.awt.key_event import KeyEvent as KeyEvent
with suppress(ImportError):
    from ...dyn.awt.key_function import KeyFunction as KeyFunction
with suppress(ImportError):
    from ...dyn.awt.key_function import KeyFunctionEnum as KeyFunctionEnum
with suppress(ImportError):
    from ...dyn.awt.key_group import KeyGroup as KeyGroup
with suppress(ImportError):
    from ...dyn.awt.key_group import KeyGroupEnum as KeyGroupEnum
with suppress(ImportError):
    from ...dyn.awt.key_modifier import KeyModifier as KeyModifier
with suppress(ImportError):
    from ...dyn.awt.key_modifier import KeyModifierEnum as KeyModifierEnum
with suppress(ImportError):
    from ...dyn.awt.key_stroke import KeyStroke as KeyStroke
with suppress(ImportError):
    from ...dyn.awt.line_end_format import LineEndFormat as LineEndFormat
with suppress(ImportError):
    from ...dyn.awt.line_end_format import LineEndFormatEnum as LineEndFormatEnum
with suppress(ImportError):
    from ...dyn.awt.menu_bar import MenuBar as MenuBar
with suppress(ImportError):
    from ...dyn.awt.menu_event import MenuEvent as MenuEvent
with suppress(ImportError):
    from ...dyn.awt.menu_item_style import MenuItemStyle as MenuItemStyle
with suppress(ImportError):
    from ...dyn.awt.menu_item_style import MenuItemStyleEnum as MenuItemStyleEnum
with suppress(ImportError):
    from ...dyn.awt.menu_item_type import MenuItemType as MenuItemType
with suppress(ImportError):
    from ...dyn.awt.message_box_buttons import MessageBoxButtons as MessageBoxButtons
with suppress(ImportError):
    from ...dyn.awt.message_box_buttons import MessageBoxButtonsEnum as MessageBoxButtonsEnum
with suppress(ImportError):
    from ...dyn.awt.message_box_results import MessageBoxResults as MessageBoxResults
with suppress(ImportError):
    from ...dyn.awt.message_box_results import MessageBoxResultsEnum as MessageBoxResultsEnum
with suppress(ImportError):
    from ...dyn.awt.message_box_type import MessageBoxType as MessageBoxType
with suppress(ImportError):
    from ...dyn.awt.mouse_button import MouseButton as MouseButton
with suppress(ImportError):
    from ...dyn.awt.mouse_button import MouseButtonEnum as MouseButtonEnum
with suppress(ImportError):
    from ...dyn.awt.mouse_event import MouseEvent as MouseEvent
with suppress(ImportError):
    from ...dyn.awt.mouse_wheel_behavior import MouseWheelBehavior as MouseWheelBehavior
with suppress(ImportError):
    from ...dyn.awt.mouse_wheel_behavior import MouseWheelBehaviorEnum as MouseWheelBehaviorEnum
with suppress(ImportError):
    from ...dyn.awt.paint_event import PaintEvent as PaintEvent
with suppress(ImportError):
    from ...dyn.awt.point import Point as Point
with suppress(ImportError):
    from ...dyn.awt.pointer import Pointer as Pointer
with suppress(ImportError):
    from ...dyn.awt.popup_menu import PopupMenu as PopupMenu
with suppress(ImportError):
    from ...dyn.awt.popup_menu_direction import PopupMenuDirection as PopupMenuDirection
with suppress(ImportError):
    from ...dyn.awt.popup_menu_direction import PopupMenuDirectionEnum as PopupMenuDirectionEnum
with suppress(ImportError):
    from ...dyn.awt.pos_size import PosSize as PosSize
with suppress(ImportError):
    from ...dyn.awt.pos_size import PosSizeEnum as PosSizeEnum
with suppress(ImportError):
    from ...dyn.awt.printer_exception import PrinterException as PrinterException
with suppress(ImportError):
    from ...dyn.awt.printer_server import PrinterServer as PrinterServer
with suppress(ImportError):
    from ...dyn.awt.push_button_type import PushButtonType as PushButtonType
with suppress(ImportError):
    from ...dyn.awt.raster_operation import RasterOperation as RasterOperation
with suppress(ImportError):
    from ...dyn.awt.rectangle import Rectangle as Rectangle
with suppress(ImportError):
    from ...dyn.awt.roadmap_item import RoadmapItem as RoadmapItem
with suppress(ImportError):
    from ...dyn.awt.scroll_bar_orientation import ScrollBarOrientation as ScrollBarOrientation
with suppress(ImportError):
    from ...dyn.awt.scroll_bar_orientation import ScrollBarOrientationEnum as ScrollBarOrientationEnum
with suppress(ImportError):
    from ...dyn.awt.selection import Selection as Selection
with suppress(ImportError):
    from ...dyn.awt.simple_font_metric import SimpleFontMetric as SimpleFontMetric
with suppress(ImportError):
    from ...dyn.awt.size import Size as Size
with suppress(ImportError):
    from ...dyn.awt.spin_event import SpinEvent as SpinEvent
with suppress(ImportError):
    from ...dyn.awt.spinning_progress_control_model import SpinningProgressControlModel as SpinningProgressControlModel
with suppress(ImportError):
    from ...dyn.awt.style import Style as Style
with suppress(ImportError):
    from ...dyn.awt.style import StyleEnum as StyleEnum
with suppress(ImportError):
    from ...dyn.awt.system_dependent_x_window import SystemDependentXWindow as SystemDependentXWindow
with suppress(ImportError):
    from ...dyn.awt.system_pointer import SystemPointer as SystemPointer
with suppress(ImportError):
    from ...dyn.awt.system_pointer import SystemPointerEnum as SystemPointerEnum
with suppress(ImportError):
    from ...dyn.awt.tab_controller import TabController as TabController
with suppress(ImportError):
    from ...dyn.awt.tab_controller_model import TabControllerModel as TabControllerModel
with suppress(ImportError):
    from ...dyn.awt.text_align import TextAlign as TextAlign
with suppress(ImportError):
    from ...dyn.awt.text_align import TextAlignEnum as TextAlignEnum
with suppress(ImportError):
    from ...dyn.awt.text_event import TextEvent as TextEvent
with suppress(ImportError):
    from ...dyn.awt.toolkit import Toolkit as Toolkit
with suppress(ImportError):
    from ...dyn.awt.uno_control import UnoControl as UnoControl
with suppress(ImportError):
    from ...dyn.awt.uno_control_button import UnoControlButton as UnoControlButton
with suppress(ImportError):
    from ...dyn.awt.uno_control_button_model import UnoControlButtonModel as UnoControlButtonModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_check_box import UnoControlCheckBox as UnoControlCheckBox
with suppress(ImportError):
    from ...dyn.awt.uno_control_check_box_model import UnoControlCheckBoxModel as UnoControlCheckBoxModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_combo_box import UnoControlComboBox as UnoControlComboBox
with suppress(ImportError):
    from ...dyn.awt.uno_control_combo_box_model import UnoControlComboBoxModel as UnoControlComboBoxModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_container import UnoControlContainer as UnoControlContainer
with suppress(ImportError):
    from ...dyn.awt.uno_control_container_model import UnoControlContainerModel as UnoControlContainerModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_currency_field import UnoControlCurrencyField as UnoControlCurrencyField
with suppress(ImportError):
    from ...dyn.awt.uno_control_currency_field_model import UnoControlCurrencyFieldModel as UnoControlCurrencyFieldModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_date_field import UnoControlDateField as UnoControlDateField
with suppress(ImportError):
    from ...dyn.awt.uno_control_date_field_model import UnoControlDateFieldModel as UnoControlDateFieldModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_dialog import UnoControlDialog as UnoControlDialog
with suppress(ImportError):
    from ...dyn.awt.uno_control_dialog_element import UnoControlDialogElement as UnoControlDialogElement
with suppress(ImportError):
    from ...dyn.awt.uno_control_dialog_model import UnoControlDialogModel as UnoControlDialogModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_dialog_model_provider import UnoControlDialogModelProvider as UnoControlDialogModelProvider
with suppress(ImportError):
    from ...dyn.awt.uno_control_edit import UnoControlEdit as UnoControlEdit
with suppress(ImportError):
    from ...dyn.awt.uno_control_edit_model import UnoControlEditModel as UnoControlEditModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_file_control import UnoControlFileControl as UnoControlFileControl
with suppress(ImportError):
    from ...dyn.awt.uno_control_file_control_model import UnoControlFileControlModel as UnoControlFileControlModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_fixed_hyperlink import UnoControlFixedHyperlink as UnoControlFixedHyperlink
with suppress(ImportError):
    from ...dyn.awt.uno_control_fixed_hyperlink_model import UnoControlFixedHyperlinkModel as UnoControlFixedHyperlinkModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_fixed_line import UnoControlFixedLine as UnoControlFixedLine
with suppress(ImportError):
    from ...dyn.awt.uno_control_fixed_line_model import UnoControlFixedLineModel as UnoControlFixedLineModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_fixed_text import UnoControlFixedText as UnoControlFixedText
with suppress(ImportError):
    from ...dyn.awt.uno_control_fixed_text_model import UnoControlFixedTextModel as UnoControlFixedTextModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_formatted_field import UnoControlFormattedField as UnoControlFormattedField
with suppress(ImportError):
    from ...dyn.awt.uno_control_formatted_field_model import UnoControlFormattedFieldModel as UnoControlFormattedFieldModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_group_box import UnoControlGroupBox as UnoControlGroupBox
with suppress(ImportError):
    from ...dyn.awt.uno_control_group_box_model import UnoControlGroupBoxModel as UnoControlGroupBoxModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_image_control import UnoControlImageControl as UnoControlImageControl
with suppress(ImportError):
    from ...dyn.awt.uno_control_image_control_model import UnoControlImageControlModel as UnoControlImageControlModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_list_box import UnoControlListBox as UnoControlListBox
with suppress(ImportError):
    from ...dyn.awt.uno_control_list_box_model import UnoControlListBoxModel as UnoControlListBoxModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_model import UnoControlModel as UnoControlModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_numeric_field import UnoControlNumericField as UnoControlNumericField
with suppress(ImportError):
    from ...dyn.awt.uno_control_numeric_field_model import UnoControlNumericFieldModel as UnoControlNumericFieldModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_pattern_field import UnoControlPatternField as UnoControlPatternField
with suppress(ImportError):
    from ...dyn.awt.uno_control_pattern_field_model import UnoControlPatternFieldModel as UnoControlPatternFieldModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_progress_bar import UnoControlProgressBar as UnoControlProgressBar
with suppress(ImportError):
    from ...dyn.awt.uno_control_progress_bar_model import UnoControlProgressBarModel as UnoControlProgressBarModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_radio_button import UnoControlRadioButton as UnoControlRadioButton
with suppress(ImportError):
    from ...dyn.awt.uno_control_radio_button_model import UnoControlRadioButtonModel as UnoControlRadioButtonModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_roadmap import UnoControlRoadmap as UnoControlRoadmap
with suppress(ImportError):
    from ...dyn.awt.uno_control_roadmap_model import UnoControlRoadmapModel as UnoControlRoadmapModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_scroll_bar import UnoControlScrollBar as UnoControlScrollBar
with suppress(ImportError):
    from ...dyn.awt.uno_control_scroll_bar_model import UnoControlScrollBarModel as UnoControlScrollBarModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_spin_button import UnoControlSpinButton as UnoControlSpinButton
with suppress(ImportError):
    from ...dyn.awt.uno_control_spin_button_model import UnoControlSpinButtonModel as UnoControlSpinButtonModel
with suppress(ImportError):
    from ...dyn.awt.uno_control_time_field import UnoControlTimeField as UnoControlTimeField
with suppress(ImportError):
    from ...dyn.awt.uno_control_time_field_model import UnoControlTimeFieldModel as UnoControlTimeFieldModel
with suppress(ImportError):
    from ...dyn.awt.vcl_container_event import VclContainerEvent as VclContainerEvent
with suppress(ImportError):
    from ...dyn.awt.vcl_window_peer_attribute import VclWindowPeerAttribute as VclWindowPeerAttribute
with suppress(ImportError):
    from ...dyn.awt.vcl_window_peer_attribute import VclWindowPeerAttributeEnum as VclWindowPeerAttributeEnum
with suppress(ImportError):
    from ...dyn.awt.visual_effect import VisualEffect as VisualEffect
with suppress(ImportError):
    from ...dyn.awt.visual_effect import VisualEffectEnum as VisualEffectEnum
with suppress(ImportError):
    from ...dyn.awt.window_attribute import WindowAttribute as WindowAttribute
with suppress(ImportError):
    from ...dyn.awt.window_attribute import WindowAttributeEnum as WindowAttributeEnum
with suppress(ImportError):
    from ...dyn.awt.window_class import WindowClass as WindowClass
with suppress(ImportError):
    from ...dyn.awt.window_descriptor import WindowDescriptor as WindowDescriptor
with suppress(ImportError):
    from ...dyn.awt.window_event import WindowEvent as WindowEvent
with suppress(ImportError):
    from ...dyn.awt.x_action_listener import XActionListener as XActionListener
with suppress(ImportError):
    from ...dyn.awt.x_activate_listener import XActivateListener as XActivateListener
with suppress(ImportError):
    from ...dyn.awt.x_adjustment_listener import XAdjustmentListener as XAdjustmentListener
with suppress(ImportError):
    from ...dyn.awt.x_animated_images import XAnimatedImages as XAnimatedImages
with suppress(ImportError):
    from ...dyn.awt.x_animation import XAnimation as XAnimation
with suppress(ImportError):
    from ...dyn.awt.x_bitmap import XBitmap as XBitmap
with suppress(ImportError):
    from ...dyn.awt.x_button import XButton as XButton
with suppress(ImportError):
    from ...dyn.awt.x_callback import XCallback as XCallback
with suppress(ImportError):
    from ...dyn.awt.x_check_box import XCheckBox as XCheckBox
with suppress(ImportError):
    from ...dyn.awt.x_combo_box import XComboBox as XComboBox
with suppress(ImportError):
    from ...dyn.awt.x_container_window_event_handler import XContainerWindowEventHandler as XContainerWindowEventHandler
with suppress(ImportError):
    from ...dyn.awt.x_container_window_provider import XContainerWindowProvider as XContainerWindowProvider
with suppress(ImportError):
    from ...dyn.awt.x_control import XControl as XControl
with suppress(ImportError):
    from ...dyn.awt.x_control_container import XControlContainer as XControlContainer
with suppress(ImportError):
    from ...dyn.awt.x_control_model import XControlModel as XControlModel
with suppress(ImportError):
    from ...dyn.awt.x_currency_field import XCurrencyField as XCurrencyField
with suppress(ImportError):
    from ...dyn.awt.x_data_transfer_provider_access import XDataTransferProviderAccess as XDataTransferProviderAccess
with suppress(ImportError):
    from ...dyn.awt.x_date_field import XDateField as XDateField
with suppress(ImportError):
    from ...dyn.awt.x_device import XDevice as XDevice
with suppress(ImportError):
    from ...dyn.awt.x_dialog import XDialog as XDialog
with suppress(ImportError):
    from ...dyn.awt.x_dialog2 import XDialog2 as XDialog2
with suppress(ImportError):
    from ...dyn.awt.x_dialog_event_handler import XDialogEventHandler as XDialogEventHandler
with suppress(ImportError):
    from ...dyn.awt.x_dialog_provider import XDialogProvider as XDialogProvider
with suppress(ImportError):
    from ...dyn.awt.x_dialog_provider2 import XDialogProvider2 as XDialogProvider2
with suppress(ImportError):
    from ...dyn.awt.x_display_bitmap import XDisplayBitmap as XDisplayBitmap
with suppress(ImportError):
    from ...dyn.awt.x_display_connection import XDisplayConnection as XDisplayConnection
with suppress(ImportError):
    from ...dyn.awt.x_dockable_window import XDockableWindow as XDockableWindow
with suppress(ImportError):
    from ...dyn.awt.x_dockable_window_listener import XDockableWindowListener as XDockableWindowListener
with suppress(ImportError):
    from ...dyn.awt.x_enhanced_mouse_click_handler import XEnhancedMouseClickHandler as XEnhancedMouseClickHandler
with suppress(ImportError):
    from ...dyn.awt.x_event_handler import XEventHandler as XEventHandler
with suppress(ImportError):
    from ...dyn.awt.x_extended_toolkit import XExtendedToolkit as XExtendedToolkit
with suppress(ImportError):
    from ...dyn.awt.x_file_dialog import XFileDialog as XFileDialog
with suppress(ImportError):
    from ...dyn.awt.x_fixed_hyperlink import XFixedHyperlink as XFixedHyperlink
with suppress(ImportError):
    from ...dyn.awt.x_fixed_text import XFixedText as XFixedText
with suppress(ImportError):
    from ...dyn.awt.x_focus_listener import XFocusListener as XFocusListener
with suppress(ImportError):
    from ...dyn.awt.x_font import XFont as XFont
with suppress(ImportError):
    from ...dyn.awt.x_font2 import XFont2 as XFont2
with suppress(ImportError):
    from ...dyn.awt.x_font_mapping_use import XFontMappingUse as XFontMappingUse
with suppress(ImportError):
    from ...dyn.awt.x_font_mapping_use_item import XFontMappingUseItem as XFontMappingUseItem
with suppress(ImportError):
    from ...dyn.awt.x_graphics import XGraphics as XGraphics
with suppress(ImportError):
    from ...dyn.awt.x_graphics2 import XGraphics2 as XGraphics2
with suppress(ImportError):
    from ...dyn.awt.x_image_button import XImageButton as XImageButton
with suppress(ImportError):
    from ...dyn.awt.x_image_consumer import XImageConsumer as XImageConsumer
with suppress(ImportError):
    from ...dyn.awt.x_image_producer import XImageProducer as XImageProducer
with suppress(ImportError):
    from ...dyn.awt.x_info_printer import XInfoPrinter as XInfoPrinter
with suppress(ImportError):
    from ...dyn.awt.x_item_event_broadcaster import XItemEventBroadcaster as XItemEventBroadcaster
with suppress(ImportError):
    from ...dyn.awt.x_item_list import XItemList as XItemList
with suppress(ImportError):
    from ...dyn.awt.x_item_list_listener import XItemListListener as XItemListListener
with suppress(ImportError):
    from ...dyn.awt.x_item_listener import XItemListener as XItemListener
with suppress(ImportError):
    from ...dyn.awt.x_key_handler import XKeyHandler as XKeyHandler
with suppress(ImportError):
    from ...dyn.awt.x_key_listener import XKeyListener as XKeyListener
with suppress(ImportError):
    from ...dyn.awt.x_layout_constrains import XLayoutConstrains as XLayoutConstrains
with suppress(ImportError):
    from ...dyn.awt.x_list_box import XListBox as XListBox
with suppress(ImportError):
    from ...dyn.awt.x_menu import XMenu as XMenu
with suppress(ImportError):
    from ...dyn.awt.x_menu_bar import XMenuBar as XMenuBar
with suppress(ImportError):
    from ...dyn.awt.x_menu_listener import XMenuListener as XMenuListener
with suppress(ImportError):
    from ...dyn.awt.x_message_box import XMessageBox as XMessageBox
with suppress(ImportError):
    from ...dyn.awt.x_message_box_factory import XMessageBoxFactory as XMessageBoxFactory
with suppress(ImportError):
    from ...dyn.awt.x_metric_field import XMetricField as XMetricField
with suppress(ImportError):
    from ...dyn.awt.x_mouse_click_handler import XMouseClickHandler as XMouseClickHandler
with suppress(ImportError):
    from ...dyn.awt.x_mouse_listener import XMouseListener as XMouseListener
with suppress(ImportError):
    from ...dyn.awt.x_mouse_motion_handler import XMouseMotionHandler as XMouseMotionHandler
with suppress(ImportError):
    from ...dyn.awt.x_mouse_motion_listener import XMouseMotionListener as XMouseMotionListener
with suppress(ImportError):
    from ...dyn.awt.x_numeric_field import XNumericField as XNumericField
with suppress(ImportError):
    from ...dyn.awt.x_paint_listener import XPaintListener as XPaintListener
with suppress(ImportError):
    from ...dyn.awt.x_pattern_field import XPatternField as XPatternField
with suppress(ImportError):
    from ...dyn.awt.x_pointer import XPointer as XPointer
with suppress(ImportError):
    from ...dyn.awt.x_popup_menu import XPopupMenu as XPopupMenu
with suppress(ImportError):
    from ...dyn.awt.x_printer import XPrinter as XPrinter
with suppress(ImportError):
    from ...dyn.awt.x_printer_property_set import XPrinterPropertySet as XPrinterPropertySet
with suppress(ImportError):
    from ...dyn.awt.x_printer_server import XPrinterServer as XPrinterServer
with suppress(ImportError):
    from ...dyn.awt.x_printer_server2 import XPrinterServer2 as XPrinterServer2
with suppress(ImportError):
    from ...dyn.awt.x_progress_bar import XProgressBar as XProgressBar
with suppress(ImportError):
    from ...dyn.awt.x_progress_monitor import XProgressMonitor as XProgressMonitor
with suppress(ImportError):
    from ...dyn.awt.x_radio_button import XRadioButton as XRadioButton
with suppress(ImportError):
    from ...dyn.awt.x_region import XRegion as XRegion
with suppress(ImportError):
    from ...dyn.awt.x_request_callback import XRequestCallback as XRequestCallback
with suppress(ImportError):
    from ...dyn.awt.x_reschedule import XReschedule as XReschedule
with suppress(ImportError):
    from ...dyn.awt.x_scroll_bar import XScrollBar as XScrollBar
with suppress(ImportError):
    from ...dyn.awt.x_simple_tab_controller import XSimpleTabController as XSimpleTabController
with suppress(ImportError):
    from ...dyn.awt.x_spin_field import XSpinField as XSpinField
with suppress(ImportError):
    from ...dyn.awt.x_spin_listener import XSpinListener as XSpinListener
with suppress(ImportError):
    from ...dyn.awt.x_spin_value import XSpinValue as XSpinValue
with suppress(ImportError):
    from ...dyn.awt.x_style_change_listener import XStyleChangeListener as XStyleChangeListener
with suppress(ImportError):
    from ...dyn.awt.x_style_settings import XStyleSettings as XStyleSettings
with suppress(ImportError):
    from ...dyn.awt.x_style_settings_supplier import XStyleSettingsSupplier as XStyleSettingsSupplier
with suppress(ImportError):
    from ...dyn.awt.x_system_child_factory import XSystemChildFactory as XSystemChildFactory
with suppress(ImportError):
    from ...dyn.awt.x_system_dependent_menu_peer import XSystemDependentMenuPeer as XSystemDependentMenuPeer
with suppress(ImportError):
    from ...dyn.awt.x_system_dependent_window_peer import XSystemDependentWindowPeer as XSystemDependentWindowPeer
with suppress(ImportError):
    from ...dyn.awt.x_tab_controller import XTabController as XTabController
with suppress(ImportError):
    from ...dyn.awt.x_tab_controller_model import XTabControllerModel as XTabControllerModel
with suppress(ImportError):
    from ...dyn.awt.x_tab_listener import XTabListener as XTabListener
with suppress(ImportError):
    from ...dyn.awt.x_text_area import XTextArea as XTextArea
with suppress(ImportError):
    from ...dyn.awt.x_text_component import XTextComponent as XTextComponent
with suppress(ImportError):
    from ...dyn.awt.x_text_edit_field import XTextEditField as XTextEditField
with suppress(ImportError):
    from ...dyn.awt.x_text_layout_constrains import XTextLayoutConstrains as XTextLayoutConstrains
with suppress(ImportError):
    from ...dyn.awt.x_text_listener import XTextListener as XTextListener
with suppress(ImportError):
    from ...dyn.awt.x_time_field import XTimeField as XTimeField
with suppress(ImportError):
    from ...dyn.awt.x_toggle_button import XToggleButton as XToggleButton
with suppress(ImportError):
    from ...dyn.awt.x_toolkit import XToolkit as XToolkit
with suppress(ImportError):
    from ...dyn.awt.x_toolkit2 import XToolkit2 as XToolkit2
with suppress(ImportError):
    from ...dyn.awt.x_toolkit3 import XToolkit3 as XToolkit3
with suppress(ImportError):
    from ...dyn.awt.x_toolkit_experimental import XToolkitExperimental as XToolkitExperimental
with suppress(ImportError):
    from ...dyn.awt.x_toolkit_robot import XToolkitRobot as XToolkitRobot
with suppress(ImportError):
    from ...dyn.awt.x_top_window import XTopWindow as XTopWindow
with suppress(ImportError):
    from ...dyn.awt.x_top_window2 import XTopWindow2 as XTopWindow2
with suppress(ImportError):
    from ...dyn.awt.x_top_window_listener import XTopWindowListener as XTopWindowListener
with suppress(ImportError):
    from ...dyn.awt.x_unit_conversion import XUnitConversion as XUnitConversion
with suppress(ImportError):
    from ...dyn.awt.x_uno_control_container import XUnoControlContainer as XUnoControlContainer
with suppress(ImportError):
    from ...dyn.awt.x_uno_control_dialog import XUnoControlDialog as XUnoControlDialog
with suppress(ImportError):
    from ...dyn.awt.x_user_input_interception import XUserInputInterception as XUserInputInterception
with suppress(ImportError):
    from ...dyn.awt.x_vcl_container import XVclContainer as XVclContainer
with suppress(ImportError):
    from ...dyn.awt.x_vcl_container_listener import XVclContainerListener as XVclContainerListener
with suppress(ImportError):
    from ...dyn.awt.x_vcl_container_peer import XVclContainerPeer as XVclContainerPeer
with suppress(ImportError):
    from ...dyn.awt.x_vcl_window_peer import XVclWindowPeer as XVclWindowPeer
with suppress(ImportError):
    from ...dyn.awt.x_view import XView as XView
with suppress(ImportError):
    from ...dyn.awt.x_window import XWindow as XWindow
with suppress(ImportError):
    from ...dyn.awt.x_window2 import XWindow2 as XWindow2
with suppress(ImportError):
    from ...dyn.awt.x_window_listener import XWindowListener as XWindowListener
with suppress(ImportError):
    from ...dyn.awt.x_window_listener2 import XWindowListener2 as XWindowListener2
with suppress(ImportError):
    from ...dyn.awt.x_window_peer import XWindowPeer as XWindowPeer



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.deployment.ui
from __future__ import annotations
import typing
from abc import abstractmethod
from ...ui.dialogs.x_asynchronous_executable_dialog import XAsynchronousExecutableDialog as XAsynchronousExecutableDialog_255014ad
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924

class PackageManagerDialog(XAsynchronousExecutableDialog_255014ad):
    """
    Service Class

    The PackageManagerDialog is used to visually manage installed packages of the user and shared installation as well as currently open documents.
    
    **since**
    
        OOo 2.0

    See Also:
        `API PackageManagerDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1deployment_1_1ui_1_1PackageManagerDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.deployment.ui'
    __ooo_full_ns__: str = 'com.sun.star.deployment.ui.PackageManagerDialog'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, xParent: XWindow_713b0924, focusedContext: str) -> None:
        """
        Create a GUI using the specific parent window and focus on the given context.
        """
        ...
    @abstractmethod
    def createAndInstall(self, extensionURL: str) -> None:
        """
        Create a GUI and pass the URL of the extension which shall be installed right away.
        
        This constructor is intended for the case when unopkg is run as result of clicking an extension in a file browser, etc. The extensions will always be installed for the current user.
        """
        ...
    @abstractmethod
    def createDefault(self) -> None:
        """
        Create a default GUI.
        """
        ...

__all__ = ['PackageManagerDialog']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_data_pilot_data_layout_field_supplier import XDataPilotDataLayoutFieldSupplier as XDataPilotDataLayoutFieldSupplier_c07142b
from .x_data_pilot_descriptor import XDataPilotDescriptor as XDataPilotDescriptor_27650f1a
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class DataPilotDescriptor(XPropertySet_bc180bfa, XDataPilotDataLayoutFieldSupplier_c07142b, XDataPilotDescriptor_27650f1a):
    """
    Service Class

    represents the description of the layout of a data pilot table.
    
    **since**
    
        OOo 3.3

    See Also:
        `API DataPilotDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ImportDescriptor(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        specifies parameters to create the data pilot table from a database.
        
        **since**
        
            OOo 3.3
        """
        ...

    @abstractproperty
    def ServiceArguments(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        specifies arguments that are passed to the implementation named by SourceServiceName.
        
        **since**
        
            OOo 3.3
        """
        ...

    @abstractproperty
    def ColumnGrand(self) -> bool:
        """
        specifies if columns for grand total results are created.
        """
        ...

    @abstractproperty
    def DrillDownOnDoubleClick(self) -> bool:
        """
        specifies whether to drill down to details or go into edit mode.
        """
        ...

    @abstractproperty
    def GrandTotalName(self) -> str:
        """
        specifies a label for grand total results.
        
        **since**
        
            OOo 3.4
        """
        ...

    @abstractproperty
    def IgnoreEmptyRows(self) -> bool:
        """
        specifies if empty rows in the source data are ignored.
        """
        ...

    @abstractproperty
    def RepeatIfEmpty(self) -> bool:
        """
        specifies if empty category cells in the source data should be treated as repetition of the content from the previous row.
        """
        ...

    @abstractproperty
    def RowGrand(self) -> bool:
        """
        specifies if rows for grand total results are created.
        """
        ...

    @abstractproperty
    def ShowFilterButton(self) -> bool:
        """
        specifies whether the filter button is shown.
        """
        ...

    @abstractproperty
    def SourceServiceName(self) -> str:
        """
        specifies the name of a DataPilotSource implementation for the data pilot table.
        
        **since**
        
            OOo 3.3
        """
        ...


__all__ = ['DataPilotDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.input
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_attributes import XAttributes as XAttributes_e31a0d36

class XElement(XInterface_8f010a43):
    """
    Capsule around an XML element.

    See Also:
        `API XElement <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1input_1_1XElement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.input'
    __ooo_full_ns__: str = 'com.sun.star.xml.input.XElement'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.input.XElement'

    @abstractmethod
    def characters(self, chars: str) -> None:
        """
        Called upon retrieval of characters.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def endElement(self) -> None:
        """
        Receives notification of element closing.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def getAttributes(self) -> XAttributes_e31a0d36:
        """
        Gets the attributes of this element.
        """
        ...
    @abstractmethod
    def getLocalName(self) -> str:
        """
        Gets the local name of this element.
        """
        ...
    @abstractmethod
    def getParent(self) -> XElement:
        """
        Gets the parent context.
        """
        ...
    @abstractmethod
    def getUid(self) -> int:
        """
        Gets the namespace uid of this element.
        """
        ...
    @abstractmethod
    def ignorableWhitespace(self, whitespace: str) -> None:
        """
        Receives notification of white space that can be ignored.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def processingInstruction(self, target: str, data: str) -> None:
        """
        Receives notification of a processing instruction.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...
    @abstractmethod
    def startChildElement(self, uid: int, localName: str, xAttributes: XAttributes_e31a0d36) -> XElement:
        """
        Called upon each occurring child element.

        Raises:
            com.sun.star.xml.sax.SAXException: ``SAXException``
        """
        ...

__all__ = ['XElement']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from .x_text import XText as XText_690408ca
    from .x_text_columns import XTextColumns as XTextColumns_b17f0bab
    from ..util.color import Color as Color_68e908c5

class TextPageStyle(ABC):
    """
    Service Class

    represents a page style for a text document.
    
    This service extends the service com.sun.star.style.PageStyle with specific properties for text documents.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API TextPageStyle <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextPageStyle.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.TextPageStyle'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def FooterText(self) -> XText_690408ca:
        """
        contains the interface to the text of the footer.
        """
        ...

    @abstractproperty
    def FooterTextFirst(self) -> XText_690408ca:
        """
        contains the interface to the text of the footer of a first page.
        
        **since**
        
            LibreOffice 4.0
        """
        ...

    @abstractproperty
    def FooterTextLeft(self) -> XText_690408ca:
        """
        contains the interface to the text of the footer of a left page.
        """
        ...

    @abstractproperty
    def FooterTextRight(self) -> XText_690408ca:
        """
        contains the interface to the text of the footer of a right page.
        """
        ...

    @abstractproperty
    def FootnoteHeight(self) -> int:
        """
        contains the maximum height of the footnote area (in 1/100 mm).
        
        If set to zero, the height of the current page is used as limit.
        """
        ...

    @abstractproperty
    def FootnoteLineAdjust(self) -> int:
        """
        contains the adjustment of the separator line between the text and the footnote area.
        """
        ...

    @abstractproperty
    def FootnoteLineColor(self) -> Color_68e908c5:
        """
        contains the color of the separator line between the text and the footnote area.
        """
        ...

    @abstractproperty
    def FootnoteLineDistance(self) -> int:
        """
        contains the distance between the footnote area and the separator line between the text and the footnote area (in 1/100 mm).
        """
        ...

    @abstractproperty
    def FootnoteLineRelativeWidth(self) -> int:
        """
        contains the relative width of the separator line between the text and the footnote area (in percent).
        """
        ...

    @abstractproperty
    def FootnoteLineTextDistance(self) -> int:
        """
        contains the distance between the text and the separator line between the text and the footnote area (in 1/100 mm).
        """
        ...

    @abstractproperty
    def FootnoteLineWeight(self) -> int:
        """
        contains the weight of the separator line between the text and the footnote area (in 1/100 mm).
        """
        ...

    @abstractproperty
    def HeaderText(self) -> XText_690408ca:
        """
        contains the interface to the text of the header.
        """
        ...

    @abstractproperty
    def HeaderTextFirst(self) -> XText_690408ca:
        """
        contains the interface to the text of the header of first pages.
        
        **since**
        
            LibreOffice 4.0
        """
        ...

    @abstractproperty
    def HeaderTextLeft(self) -> XText_690408ca:
        """
        contains the interface to the text of the header of left pages.
        """
        ...

    @abstractproperty
    def HeaderTextRight(self) -> XText_690408ca:
        """
        contains the interface to the text of the header of right pages.
        """
        ...

    @abstractproperty
    def RegisterModeActive(self) -> bool:
        """
        determines whether the register mode is active on that page.
        """
        ...

    @abstractproperty
    def RegisterParagraphStyle(self) -> str:
        """
        contains the name of the paragraph style that is used as reference of the register mode.
        """
        ...

    @abstractproperty
    def TextColumns(self) -> XTextColumns_b17f0bab:
        """
        contains the column settings of the page.
        """
        ...


__all__ = ['TextPageStyle']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.uri
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_uri_reference import XUriReference as XUriReference_afc30b6f
    from com.sun.star.uri.RelativeUriExcessParentSegments import RelativeUriExcessParentSegmentsProto  # type: ignore

class XUriReferenceFactory(XInterface_8f010a43):
    """
    creates URI references.
    
    See RFC 3986 for a description of URI references and related terms.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XUriReferenceFactory <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1uri_1_1XUriReferenceFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.uri'
    __ooo_full_ns__: str = 'com.sun.star.uri.XUriReferenceFactory'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.uri.XUriReferenceFactory'

    @abstractmethod
    def makeAbsolute(self, baseUriReference: XUriReference_afc30b6f, uriReference: XUriReference_afc30b6f, processAdditionalSpecialSegments: bool, excessParentSegments: RelativeUriExcessParentSegmentsProto) -> XUriReference_afc30b6f:
        """
        resolves a relative URI reference to absolute form.
        """
        ...
    @abstractmethod
    def makeRelative(self, baseUriReference: XUriReference_afc30b6f, uriReference: XUriReference_afc30b6f, preferAuthorityOverRelativePath: bool, preferAbsoluteOverRelativePath: bool, encodeRetainedSpecialSegments: bool) -> XUriReference_afc30b6f:
        """
        changes an absolute URI reference to relative form.
        """
        ...
    @abstractmethod
    def parse(self, uriReference: str) -> XUriReference_afc30b6f:
        """
        parses the textual representation of a URI reference.
        """
        ...

__all__ = ['XUriReferenceFactory']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.xml.dom.dom_exception import DOMException as DOMException
with suppress(ImportError):
    from ....dyn.xml.dom.dom_exception_type import DOMExceptionType as DOMExceptionType
with suppress(ImportError):
    from ....dyn.xml.dom.document_builder import DocumentBuilder as DocumentBuilder
with suppress(ImportError):
    from ....dyn.xml.dom.node_type import NodeType as NodeType
with suppress(ImportError):
    from ....dyn.xml.dom.sax_document_builder import SAXDocumentBuilder as SAXDocumentBuilder
with suppress(ImportError):
    from ....dyn.xml.dom.sax_document_builder_state import SAXDocumentBuilderState as SAXDocumentBuilderState
with suppress(ImportError):
    from ....dyn.xml.dom.x_attr import XAttr as XAttr
with suppress(ImportError):
    from ....dyn.xml.dom.xcdata_section import XCDATASection as XCDATASection
with suppress(ImportError):
    from ....dyn.xml.dom.x_character_data import XCharacterData as XCharacterData
with suppress(ImportError):
    from ....dyn.xml.dom.x_comment import XComment as XComment
with suppress(ImportError):
    from ....dyn.xml.dom.xdom_implementation import XDOMImplementation as XDOMImplementation
with suppress(ImportError):
    from ....dyn.xml.dom.x_document import XDocument as XDocument
with suppress(ImportError):
    from ....dyn.xml.dom.x_document_builder import XDocumentBuilder as XDocumentBuilder
with suppress(ImportError):
    from ....dyn.xml.dom.x_document_fragment import XDocumentFragment as XDocumentFragment
with suppress(ImportError):
    from ....dyn.xml.dom.x_document_type import XDocumentType as XDocumentType
with suppress(ImportError):
    from ....dyn.xml.dom.x_element import XElement as XElement
with suppress(ImportError):
    from ....dyn.xml.dom.x_entity import XEntity as XEntity
with suppress(ImportError):
    from ....dyn.xml.dom.x_entity_reference import XEntityReference as XEntityReference
with suppress(ImportError):
    from ....dyn.xml.dom.x_named_node_map import XNamedNodeMap as XNamedNodeMap
with suppress(ImportError):
    from ....dyn.xml.dom.x_node import XNode as XNode
with suppress(ImportError):
    from ....dyn.xml.dom.x_node_list import XNodeList as XNodeList
with suppress(ImportError):
    from ....dyn.xml.dom.x_notation import XNotation as XNotation
with suppress(ImportError):
    from ....dyn.xml.dom.x_processing_instruction import XProcessingInstruction as XProcessingInstruction
with suppress(ImportError):
    from ....dyn.xml.dom.xsax_document_builder import XSAXDocumentBuilder as XSAXDocumentBuilder
with suppress(ImportError):
    from ....dyn.xml.dom.xsax_document_builder2 import XSAXDocumentBuilder2 as XSAXDocumentBuilder2
with suppress(ImportError):
    from ....dyn.xml.dom.x_text import XText as XText



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty
from .text_frame import TextFrame as TextFrame_90410a5d

class ChainedTextFrame(TextFrame_90410a5d):
    """
    Service Class

    extends a TextFrame which shares the same Text with other ChainedTextFrame instances that will make the text flow through the chained frames.
    
    The text flows in the next frame if there is no space left in the current frame.

    See Also:
        `API ChainedTextFrame <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1ChainedTextFrame.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.ChainedTextFrame'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ChainNextName(self) -> str:
        """
        name of the previous frame in the chain
        
        An empty string indicates that there is no previous frame.
        """
        ...

    @abstractproperty
    def ChainPrevName(self) -> str:
        """
        name of the next frame in the chain
        
        An empty string indicates that there is no next frame.
        """
        ...


__all__ = ['ChainedTextFrame']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui.dialogs
from __future__ import annotations
from ...beans.x_property_access import XPropertyAccess as XPropertyAccess_e1d40d20
from .x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1

class FilterOptionsDialog(XPropertyAccess_e1d40d20, XExecutableDialog_450f0fa1):
    """
    Service Class

    This service enables a filter developer to register a dialog to query for user options before the filter operation is performed.
    
    The user options are stored inside the com.sun.star.document.MediaDescriptor and can be queried from the com.sun.star.document.MediaDescriptor by the component that implements com.sun.star.document.XFilter.
    
    The application will set the com.sun.star.document.MediaDescriptor using the interface com.sun.star.beans.XPropertyAccess and then call XExecutableDialog.execute().
    
    If that method returns ExecutableDialogResults.OK, the application will retrieve the changed com.sun.star.document.MediaDescriptor back using the interface com.sun.star.beans.XPropertyAccess. The filter operation is then continued, using the new com.sun.star.document.MediaDescriptor.
    
    Otherwise, the filter operation is canceled.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API FilterOptionsDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1FilterOptionsDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui.dialogs'
    __ooo_full_ns__: str = 'com.sun.star.ui.dialogs.FilterOptionsDialog'
    __ooo_type_name__: str = 'service'


__all__ = ['FilterOptionsDialog']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .text_conversion_result import TextConversionResult as TextConversionResult_12d10e92
    from ..lang.locale import Locale as Locale_70d308fa

class XTextConversion(XInterface_8f010a43):
    """
    Method to convert text from one type to another.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XTextConversion <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XTextConversion.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XTextConversion'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XTextConversion'

    @abstractmethod
    def getConversion(self, aText: str, nStartPos: int, nLength: int, Locale: Locale_70d308fa, nTextConversionType: int, nTextConversionOptions: int) -> str:
        """
        Method to search dictionaries for the conversion candidate, if there are multiple candidates, it will return first one.
        
        This is for the conversion in non-interactive mode.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def getConversions(self, aText: str, nStartPos: int, nLength: int, Locale: Locale_70d308fa, nTextConversionType: int, nTextConversionOptions: int) -> TextConversionResult_12d10e92:
        """
        Method to search dictionaries for the conversion candidates.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def interactiveConversion(self, Locale: Locale_70d308fa, nTextConversionType: int, nTextConversionOptions: int) -> bool:
        """
        Method to query if the conversion type should be interactive or non-interactive mode.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...

__all__ = ['XTextConversion']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.util.alias_programmatic_pair import AliasProgrammaticPair as AliasProgrammaticPair
from ...lo.util.atom_class_request import AtomClassRequest as AtomClassRequest
from ...lo.util.atom_description import AtomDescription as AtomDescription
from ...lo.util.bootstrap_macro_expander import BootstrapMacroExpander as BootstrapMacroExpander
from ...lo.util.cell_protection import CellProtection as CellProtection
from ...lo.util.changes_event import ChangesEvent as ChangesEvent
from ...lo.util.changes_set import ChangesSet as ChangesSet
from ...lo.util.close_veto_exception import CloseVetoException as CloseVetoException
from ...lo.util.color import Color as Color
from ...lo.util.data_editor_event import DataEditorEvent as DataEditorEvent
from ...lo.util.data_editor_event_type import DataEditorEventType as DataEditorEventType
from ...lo.util.date import Date as Date
from ...lo.util.date_time import DateTime as DateTime
from ...lo.util.date_time_range import DateTimeRange as DateTimeRange
from ...lo.util.date_time_with_timezone import DateTimeWithTimezone as DateTimeWithTimezone
from ...lo.util.date_with_timezone import DateWithTimezone as DateWithTimezone
from ...lo.util.duration import Duration as Duration
from ...lo.util.element_change import ElementChange as ElementChange
from ...lo.util.endianness import Endianness as Endianness
from ...lo.util.invalid_state_exception import InvalidStateException as InvalidStateException
from ...lo.util.job_manager import JobManager as JobManager
from ...lo.util.language import Language as Language
from ...lo.util.macro_expander import MacroExpander as MacroExpander
from ...lo.util.malformed_number_format_exception import MalformedNumberFormatException as MalformedNumberFormatException
from ...lo.util.measure_unit import MeasureUnit as MeasureUnit
from ...lo.util.mode_change_event import ModeChangeEvent as ModeChangeEvent
from ...lo.util.not_locked_exception import NotLockedException as NotLockedException
from ...lo.util.not_numeric_exception import NotNumericException as NotNumericException
from ...lo.util.number_format import NumberFormat as NumberFormat
from ...lo.util.number_format_properties import NumberFormatProperties as NumberFormatProperties
from ...lo.util.number_format_settings import NumberFormatSettings as NumberFormatSettings
from ...lo.util.number_formats import NumberFormats as NumberFormats
from ...lo.util.number_formats_supplier import NumberFormatsSupplier as NumberFormatsSupplier
from ...lo.util.number_formatter import NumberFormatter as NumberFormatter
from ...lo.util.office_installation_directories import OfficeInstallationDirectories as OfficeInstallationDirectories
from ...lo.util.path_settings import PathSettings as PathSettings
from ...lo.util.path_substitution import PathSubstitution as PathSubstitution
from ...lo.util.replace_descriptor import ReplaceDescriptor as ReplaceDescriptor
from ...lo.util.revision_tag import RevisionTag as RevisionTag
from ...lo.util.search_algorithms import SearchAlgorithms as SearchAlgorithms
from ...lo.util.search_algorithms2 import SearchAlgorithms2 as SearchAlgorithms2
from ...lo.util.search_descriptor import SearchDescriptor as SearchDescriptor
from ...lo.util.search_flags import SearchFlags as SearchFlags
from ...lo.util.search_options import SearchOptions as SearchOptions
from ...lo.util.search_options2 import SearchOptions2 as SearchOptions2
from ...lo.util.search_result import SearchResult as SearchResult
from ...lo.util.sort_descriptor import SortDescriptor as SortDescriptor
from ...lo.util.sort_descriptor2 import SortDescriptor2 as SortDescriptor2
from ...lo.util.sort_field import SortField as SortField
from ...lo.util.sort_field_type import SortFieldType as SortFieldType
from ...lo.util.sortable import Sortable as Sortable
from ...lo.util.text_search import TextSearch as TextSearch
from ...lo.util.text_search2 import TextSearch2 as TextSearch2
from ...lo.util.time import Time as Time
from ...lo.util.time_with_timezone import TimeWithTimezone as TimeWithTimezone
from ...lo.util.tri_state import TriState as TriState
from ...lo.util.url import URL as URL
from ...lo.util.url_transformer import URLTransformer as URLTransformer
from ...lo.util.uri_abbreviation import UriAbbreviation as UriAbbreviation
from ...lo.util.veto_exception import VetoException as VetoException
from ...lo.util.x_accounting import XAccounting as XAccounting
from ...lo.util.x_atom_server import XAtomServer as XAtomServer
from ...lo.util.x_binary_data_container import XBinaryDataContainer as XBinaryDataContainer
from ...lo.util.x_broadcaster import XBroadcaster as XBroadcaster
from ...lo.util.x_cache_info import XCacheInfo as XCacheInfo
from ...lo.util.x_cancellable import XCancellable as XCancellable
from ...lo.util.x_chainable import XChainable as XChainable
from ...lo.util.x_changes_batch import XChangesBatch as XChangesBatch
from ...lo.util.x_changes_listener import XChangesListener as XChangesListener
from ...lo.util.x_changes_notifier import XChangesNotifier as XChangesNotifier
from ...lo.util.x_changes_set import XChangesSet as XChangesSet
from ...lo.util.x_cloneable import XCloneable as XCloneable
from ...lo.util.x_close_broadcaster import XCloseBroadcaster as XCloseBroadcaster
from ...lo.util.x_close_listener import XCloseListener as XCloseListener
from ...lo.util.x_closeable import XCloseable as XCloseable
from ...lo.util.x_data_editor import XDataEditor as XDataEditor
from ...lo.util.x_data_editor_listener import XDataEditorListener as XDataEditorListener
from ...lo.util.x_flush_listener import XFlushListener as XFlushListener
from ...lo.util.x_flushable import XFlushable as XFlushable
from ...lo.util.x_importable import XImportable as XImportable
from ...lo.util.x_indent import XIndent as XIndent
from ...lo.util.x_job_manager import XJobManager as XJobManager
from ...lo.util.x_link_update import XLinkUpdate as XLinkUpdate
from ...lo.util.x_localized_aliases import XLocalizedAliases as XLocalizedAliases
from ...lo.util.x_lockable import XLockable as XLockable
from ...lo.util.x_macro_expander import XMacroExpander as XMacroExpander
from ...lo.util.x_mergeable import XMergeable as XMergeable
from ...lo.util.x_mode_change_approve_listener import XModeChangeApproveListener as XModeChangeApproveListener
from ...lo.util.x_mode_change_broadcaster import XModeChangeBroadcaster as XModeChangeBroadcaster
from ...lo.util.x_mode_change_listener import XModeChangeListener as XModeChangeListener
from ...lo.util.x_mode_selector import XModeSelector as XModeSelector
from ...lo.util.x_modifiable import XModifiable as XModifiable
from ...lo.util.x_modifiable2 import XModifiable2 as XModifiable2
from ...lo.util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster
from ...lo.util.x_modify_listener import XModifyListener as XModifyListener
from ...lo.util.x_number_format_previewer import XNumberFormatPreviewer as XNumberFormatPreviewer
from ...lo.util.x_number_format_types import XNumberFormatTypes as XNumberFormatTypes
from ...lo.util.x_number_formats import XNumberFormats as XNumberFormats
from ...lo.util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier
from ...lo.util.x_number_formatter import XNumberFormatter as XNumberFormatter
from ...lo.util.x_number_formatter2 import XNumberFormatter2 as XNumberFormatter2
from ...lo.util.x_office_installation_directories import XOfficeInstallationDirectories as XOfficeInstallationDirectories
from ...lo.util.x_path_settings import XPathSettings as XPathSettings
from ...lo.util.x_property_replace import XPropertyReplace as XPropertyReplace
from ...lo.util.x_protectable import XProtectable as XProtectable
from ...lo.util.x_refresh_listener import XRefreshListener as XRefreshListener
from ...lo.util.x_refreshable import XRefreshable as XRefreshable
from ...lo.util.x_replace_descriptor import XReplaceDescriptor as XReplaceDescriptor
from ...lo.util.x_replaceable import XReplaceable as XReplaceable
from ...lo.util.x_search_descriptor import XSearchDescriptor as XSearchDescriptor
from ...lo.util.x_searchable import XSearchable as XSearchable
from ...lo.util.x_sortable import XSortable as XSortable
from ...lo.util.x_string_abbreviation import XStringAbbreviation as XStringAbbreviation
from ...lo.util.x_string_escape import XStringEscape as XStringEscape
from ...lo.util.x_string_mapping import XStringMapping as XStringMapping
from ...lo.util.x_string_substitution import XStringSubstitution as XStringSubstitution
from ...lo.util.x_string_width import XStringWidth as XStringWidth
from ...lo.util.x_text_search import XTextSearch as XTextSearch
from ...lo.util.x_text_search2 import XTextSearch2 as XTextSearch2
from ...lo.util.x_time_stamped import XTimeStamped as XTimeStamped
from ...lo.util.xurl_transformer import XURLTransformer as XURLTransformer
from ...lo.util.x_unique_id_factory import XUniqueIDFactory as XUniqueIDFactory
from ...lo.util.x_updatable import XUpdatable as XUpdatable
from ...lo.util.x_updatable2 import XUpdatable2 as XUpdatable2
from ...lo.util.x_veto import XVeto as XVeto
from ...lo.util.the_macro_expander import theMacroExpander as theMacroExpander
from ...lo.util.the_office_installation_directories import theOfficeInstallationDirectories as theOfficeInstallationDirectories
from ...lo.util.the_path_settings import thePathSettings as thePathSettings



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class FolderListEntry(object):
    """
    Struct Class

    Information about a single folder in a FolderList.

    See Also:
        `API FolderListEntry <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1FolderListEntry.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.FolderListEntry'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.FolderListEntry'
    """Literal Constant ``com.sun.star.ucb.FolderListEntry``"""

    def __init__(self, Title: typing.Optional[str] = '', ID: typing.Optional[str] = '', Subscribed: typing.Optional[bool] = False, New: typing.Optional[bool] = False, Removed: typing.Optional[bool] = False, Purge: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Title (str, optional): Title value.
            ID (str, optional): ID value.
            Subscribed (bool, optional): Subscribed value.
            New (bool, optional): New value.
            Removed (bool, optional): Removed value.
            Purge (bool, optional): Purge value.
        """
        super().__init__()

        if isinstance(Title, FolderListEntry):
            oth: FolderListEntry = Title
            self.Title = oth.Title
            self.ID = oth.ID
            self.Subscribed = oth.Subscribed
            self.New = oth.New
            self.Removed = oth.Removed
            self.Purge = oth.Purge
            return

        kargs = {
            "Title": Title,
            "ID": ID,
            "Subscribed": Subscribed,
            "New": New,
            "Removed": Removed,
            "Purge": Purge,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._title = kwargs["Title"]
        self._id = kwargs["ID"]
        self._subscribed = kwargs["Subscribed"]
        self._new = kwargs["New"]
        self._removed = kwargs["Removed"]
        self._purge = kwargs["Purge"]


    @property
    def Title(self) -> str:
        """
        The title of the folder.
        """
        return self._title

    @Title.setter
    def Title(self, value: str) -> None:
        self._title = value

    @property
    def ID(self) -> str:
        """
        A (unique) identifier for the folder (used by IMAP, where different folders with equal human-readable titles may exist; otherwise, it may be left empty).
        """
        return self._id

    @ID.setter
    def ID(self, value: str) -> None:
        self._id = value

    @property
    def Subscribed(self) -> bool:
        """
        The folder is subscribed.
        """
        return self._subscribed

    @Subscribed.setter
    def Subscribed(self, value: bool) -> None:
        self._subscribed = value

    @property
    def New(self) -> bool:
        """
        The folder is new.
        """
        return self._new

    @New.setter
    def New(self, value: bool) -> None:
        self._new = value

    @property
    def Removed(self) -> bool:
        """
        The folder has been removed.
        """
        return self._removed

    @Removed.setter
    def Removed(self, value: bool) -> None:
        self._removed = value

    @property
    def Purge(self) -> bool:
        """
        The folder shall be purged (only used in conjunction with the FolderListCommand.SET).
        """
        return self._purge

    @Purge.setter
    def Purge(self, value: bool) -> None:
        self._purge = value


__all__ = ['FolderListEntry']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_common_embed_persist import XCommonEmbedPersist as XCommonEmbedPersist_16930e8d
if typing.TYPE_CHECKING:
    from .x_storage import XStorage as XStorage_8e460a32

class XLinkageSupport(XCommonEmbedPersist_16930e8d):
    """
    specifies an additional implementation for linked embedded object support.

    See Also:
        `API XLinkageSupport <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XLinkageSupport.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XLinkageSupport'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XLinkageSupport'

    @abstractmethod
    def breakLink(self, xStorage: XStorage_8e460a32, sEntryName: str) -> None:
        """
        breaks the link and provides the object with a parent storage and a name for object's entry
        
        This method can be used only for links implementations that implement the whole set of embedded object interfaces. Usually the sets of interfaces are the same for links and objects. An example of exception from this are OOo links that do not implement XEmbedPersist interface. For such cases the method will throw an exception.
        
        The link will be broken and the linked object will become a normal embedded object.
        
        An entry with the specified name should be created or opened inside provided storage. This entry will be used for the object persistence. If the entry exists already all its contents will be ignored.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.io.IOException: ``IOException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def getLinkURL(self) -> str:
        """
        returns the URL of the link object.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def isLink(self) -> bool:
        """
        allows to detect whether the object is a linked one.
        
        Most of embedded objects will not support this interface, but some of them can do it, to allow conversion from link to object. After the conversion the object does not change, so interface set stays the same, but the object is not a link any more.

        Raises:
            com.sun.star.embed.WrongStateException: ``WrongStateException``
        """
        ...

__all__ = ['XLinkageSupport']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from .x_invocation import XInvocation as XInvocation_be070c0f

class XAutomationInvocation(XInvocation_be070c0f):
    """

    See Also:
        `API XAutomationInvocation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XAutomationInvocation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XAutomationInvocation'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XAutomationInvocation'

    @abstractmethod
    def invokeGetProperty(self, aFunctionName: str, aParams: typing.Tuple[object, ...], aOutParamIndex: uno.ByteSequence, aOutParam: typing.Tuple[object, ...]) -> object:
        """

        * ``aOutParamIndex`` is an out direction argument.
        * ``aOutParam`` is an out direction argument.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.script.CannotConvertException: ``CannotConvertException``
            com.sun.star.reflection.InvocationTargetException: ``InvocationTargetException``
        """
        ...
    @abstractmethod
    def invokePutProperty(self, aFunctionName: str, aParams: typing.Tuple[object, ...], aOutParamIndex: uno.ByteSequence, aOutParam: typing.Tuple[object, ...]) -> object:
        """

        * ``aOutParamIndex`` is an out direction argument.
        * ``aOutParam`` is an out direction argument.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.script.CannotConvertException: ``CannotConvertException``
            com.sun.star.reflection.InvocationTargetException: ``InvocationTargetException``
        """
        ...

__all__ = ['XAutomationInvocation']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.accessibility
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XAccessibleTextAttributes(ABC):
    """
    Implement this interface to give access to the attributes of a text.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API XAccessibleTextAttributes <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleTextAttributes.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.accessibility'
    __ooo_full_ns__: str = 'com.sun.star.accessibility.XAccessibleTextAttributes'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.accessibility.XAccessibleTextAttributes'

    @abstractmethod
    def getDefaultAttributes(self, RequestedAttributes: typing.Tuple[str, ...]) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Get the default attribute set for the text.
        
        Returns a set of all default paragraph and default character attributes that are associated for the text. To prevent the method from returning possibly large sets of attributes that the caller is not interested in the caller can provide a list of attributes that he wants to be returned.
        
        When the sequence is empty all attributes are returned.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
        """
        ...
    @abstractmethod
    def getRunAttributes(self, Index: int, RequestedAttributes: typing.Tuple[str, ...]) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Get the run attribute set for the specified position.
        
        Returns a set of character attributes that are associated for the character at the given index and are directly set or are set via a character style. To prevent the method from returning all of these attributes the caller can provide a list of attributes that he wants to be returned.
        
        When the sequence is empty all attributes are returned.

        Raises:
            com.sun.star.beans.UnknownPropertyException: ``UnknownPropertyException``
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...

__all__ = ['XAccessibleTextAttributes']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_chart_type import XChartType as XChartType_ad200b38
    from .x_data_series import XDataSeries as XDataSeries_b8150b89
    from .x_diagram import XDiagram as XDiagram_96fe0a59
    from .data.x_data_source import XDataSource as XDataSource_f6340d57

class XChartTypeTemplate(XInterface_8f010a43):
    """

    See Also:
        `API XChartTypeTemplate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartTypeTemplate.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XChartTypeTemplate'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XChartTypeTemplate'

    @abstractmethod
    def applyStyle(self, xSeries: XDataSeries_b8150b89, nChartTypeGroupIndex: int, nSeriesIndex: int, nSeriesCount: int) -> None:
        """
        Applies a chart-type specific style (e.g.
        
        symbols) to all series in the sequence aSeries.
        """
        ...
    @abstractmethod
    def changeDiagram(self, xDiagram: XDiagram_96fe0a59) -> None:
        """
        Analyses the given diagram and reinterprets its DataSeries and Categories and creates a new diagram based on these series.
        
        Note, that if matchesTemplate() returns TRUE for the given XDiagram, the latter should not be changed.
        """
        ...
    @abstractmethod
    def changeDiagramData(self, xDiagram: XDiagram_96fe0a59, xDataSource: XDataSource_f6340d57, aArguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        Changes the given diagram xDiagram by using the new data given in xDataSource.
        
        Note that the data is interpreted in a way that fits this template, but not necessarily the chart-types of the diagram. This method should only be called if the data-format of the diagram is compatible with the data-format of this template.
        
        Ideally a matchesTemplate() call for the given diagram should return TRUE before this method is called.
        
        For standard parameters that may be used, see the service StandardDiagramCreationParameters.
        """
        ...
    @abstractmethod
    def createDiagramByDataSource(self, xDataSource: XDataSource_f6340d57, aArguments: typing.Tuple[PropertyValue_c9610c73, ...]) -> XDiagram_96fe0a59:
        """
        Creates a new diagram based upon the given data .
        
        For standard parameters that may be used, see the service StandardDiagramCreationParameters.
        """
        ...
    @abstractmethod
    def getChartTypeForNewSeries(self, aFormerlyUsedChartTypes: typing.Tuple[XChartType_ad200b38, ...]) -> XChartType_ad200b38:
        """
        Provides a chart type object that can be used to create new series.
        """
        ...
    @abstractmethod
    def getDataInterpreter(self) -> XInterface_8f010a43:
        """
        This used to have a return type of XDataInterpreter.
        
        Then I removed the whole XChartTypeTemplate interface in commit 58766f997d59e4684f2887fd8cdeb12d2f8a9366. Which turned out to be a bad idea, so I restored it. I restored it in this form because I want to restore binary compatibily with vtable layout, but I don't want to restore the XDataInterpreter stuff, which was not useful for external use.
        """
        ...
    @abstractmethod
    def matchesTemplate(self, xDiagram: XDiagram_96fe0a59, bAdaptProperties: bool) -> bool:
        """
        States whether the given diagram could have been created by the template.
        
        The template will parse the DataSeriesTree of the diagram to determine if the structure matches the one which would have been created by createDiagramByDataSource().
        
        For analysis all parts of the diagram may be used, e.g. also properties set at the data series (like symbols)./p>
        """
        ...
    @abstractmethod
    def resetStyles(self, xDiagram: XDiagram_96fe0a59) -> None:
        """
        Resets all styles that were changed from the default at any object in the chart and have not been later modified.
        
        In createDiagramByDataSource() or changeDiagram() a template might e.g. change the page background color or the line style of all data series. This method should reset all objects that still have the changed settings to the default.
        
        If for example the template changed the com.sun.star.drawing.LineStyle of all series to NONE, this method should reset all series with LineStyle NONE back to SOLID. If a series has a style DASH, it must not be changed.
        """
        ...
    @abstractmethod
    def supportsCategories(self) -> bool:
        """
        """
        ...

__all__ = ['XChartTypeTemplate']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..document.settings import Settings as Settings_b2bc0bb8
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5

class DocumentSettings(Settings_b2bc0bb8):
    """
    Service Class

    describes properties that apply to the whole spreadsheet document.
    
    For settings that affect view properties, these settings apply to subsequently created views and are saved with the document, while SpreadsheetViewSettings can be used to alter a specific view that is already open.

    See Also:
        `API DocumentSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DocumentSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DocumentSettings'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def GridColor(self) -> Color_68e908c5:
        """
        specifies the color in which the cell grid is displayed.
        """
        ...

    @abstractproperty
    def HasColumnRowHeaders(self) -> bool:
        """
        enables the column and row headers of the view.
        """
        ...

    @abstractproperty
    def HasSheetTabs(self) -> bool:
        """
        enables the sheet tabs of the view.
        """
        ...

    @abstractproperty
    def IsDocumentShared(self) -> bool:
        """
        enables the document sharing feature (Tools->Share Spreadsheet)
        """
        ...

    @abstractproperty
    def IsOutlineSymbolsSet(self) -> bool:
        """
        enables the display of outline symbols.
        """
        ...

    @abstractproperty
    def IsRasterAxisSynchronized(self) -> bool:
        """
        enables the synchronization of horizontal and vertical grid settings in the user interface.
        """
        ...

    @abstractproperty
    def IsSnapToRaster(self) -> bool:
        """
        enables the restriction of object movement and resizing of drawing objects to the raster.
        """
        ...

    @abstractproperty
    def RasterIsVisible(self) -> bool:
        """
        enables the display of the drawing object raster.
        """
        ...

    @abstractproperty
    def RasterResolutionX(self) -> int:
        """
        specifies the distance between horizontal grid elements in 1/100 mm.
        """
        ...

    @abstractproperty
    def RasterResolutionY(self) -> int:
        """
        specifies the distance between vertical grid elements in 1/100 mm.
        """
        ...

    @abstractproperty
    def RasterSubdivisionX(self) -> int:
        """
        specifies the number of subdivisions between two horizontal grid elements.
        """
        ...

    @abstractproperty
    def RasterSubdivisionY(self) -> int:
        """
        specifies the number of subdivisions between two vertical grid elements.
        """
        ...

    @abstractproperty
    def ShowGrid(self) -> bool:
        """
        enables the display of the cell grid.
        """
        ...

    @abstractproperty
    def ShowNotes(self) -> bool:
        """
        controls whether a marker is shown for notes in cells.
        """
        ...

    @abstractproperty
    def ShowPageBreaks(self) -> bool:
        """
        enables display of page breaks.
        """
        ...

    @abstractproperty
    def ShowZeroValues(self) -> bool:
        """
        enables display of zero-values.
        """
        ...


__all__ = ['DocumentSettings']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XCellRangeData(XInterface_8f010a43):
    """
    allows to get and set an array of data from a cell range.
    
    The outer sequence represents the rows and the inner sequence the columns of the array.

    See Also:
        `API XCellRangeData <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XCellRangeData.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XCellRangeData'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XCellRangeData'

    @abstractmethod
    def getDataArray(self) -> typing.Tuple[typing.Tuple[object, ...], ...]:
        """
        gets an array from the contents of the cell range.
        
        Each element of the result contains a double or a string.
        """
        ...
    @abstractmethod
    def setDataArray(self, aArray: typing.Tuple[typing.Tuple[object, ...], ...]) -> None:
        """
        fills the cell range with values from an array.
        
        The size of the array must be the same as the size of the cell range. Each element of the array must contain a double or a string.
        """
        ...

__all__ = ['XCellRangeData']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class EventTrigger(metaclass=UnoConstMeta, type_name="com.sun.star.animations.EventTrigger", name_space="com.sun.star.animations"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.animations.EventTrigger``"""
        pass

    class EventTriggerEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.animations.EventTrigger", name_space="com.sun.star.animations"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.animations.EventTrigger`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.animations import EventTrigger as EventTrigger
    else:
        # keep document generators happy
        from ...lo.animations.event_trigger import EventTrigger as EventTrigger

    class EventTriggerEnum(IntEnum):
        """
        Enum of Const Class EventTrigger

        """
        NONE = EventTrigger.NONE
        """
        Nothing triggers this event.
        """
        ON_BEGIN = EventTrigger.ON_BEGIN
        ON_END = EventTrigger.ON_END
        BEGIN_EVENT = EventTrigger.BEGIN_EVENT
        """
        This event is raised when the element local timeline begins to play.
        
        It will be raised each time the element begins the active duration (i.e. when it restarts, but not when it repeats).
        """
        END_EVENT = EventTrigger.END_EVENT
        """
        This event is raised at the active end of the element.
        
        Note that this event is not raised at the simple end of each repeat.
        """
        ON_CLICK = EventTrigger.ON_CLICK
        ON_DBL_CLICK = EventTrigger.ON_DBL_CLICK
        ON_MOUSE_ENTER = EventTrigger.ON_MOUSE_ENTER
        ON_MOUSE_LEAVE = EventTrigger.ON_MOUSE_LEAVE
        ON_NEXT = EventTrigger.ON_NEXT
        """
        This event is raised when the user wants the presentation to go one step forward.
        """
        ON_PREV = EventTrigger.ON_PREV
        """
        This event is raised when the user wants the presentation to go one step backward.
        """
        ON_STOP_AUDIO = EventTrigger.ON_STOP_AUDIO
        REPEAT = EventTrigger.REPEAT
        """
        This event is raised when the element local timeline repeats.
        
        It will be raised each time the element repeats, after the first iteration.
        """

__all__ = ['EventTrigger', 'EventTriggerEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing

from ...lo.drawing.drawing_document import DrawingDocument as DrawingDocument

__all__ = ['DrawingDocument']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.view
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..awt.x_device import XDevice as XDevice_70ba08fc

class RenderOptions(ABC):
    """
    Service Class

    describes the options for Render jobs.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API RenderOptions <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1view_1_1RenderOptions.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.RenderOptions'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsFirstPage(self) -> bool:
        """
        indicates that the current page is the first page to be exported.
        
        Hyperlinks, notes, and outlines cannot be exported on a per page base. They have to be exported once before the first page is exported. Therefore the IsFirstPage property has been introduced. It is evaluated in the render function and indicates that the current page is the first page to be exported.
        """
        ...

    @abstractproperty
    def IsLastPage(self) -> bool:
        """
        indicates that the current page is the last page to be exported.
        
        Hyperlinks from the EditEngine have to be exported once after the last page has been processed. Therefore the IsLastPage property has been introduced. It is evaluated in the render function and indicates that the current page is the last page to be exported.
        """
        ...

    @abstractproperty
    def IsSkipEmptyPages(self) -> bool:
        """
        specifies if empty pages should be skipped.
        
        Tells the PDF export to skip empty pages. This flag also has to be passed to the render function, in order to calculate to correct page numbers during the export of hyperlinks, notes, and outlines.
        """
        ...

    @abstractproperty
    def PageRange(self) -> str:
        """
        specifies the page ranges to be rendered.
        
        Tells the PDF export to skip empty pages. This flag also has to be passed to the render function, in order to calculate to correct page numbers during the export of hyperlinks, notes, and outlines.
        """
        ...

    @abstractproperty
    def RenderDevice(self) -> XDevice_70ba08fc:
        """
        specifies the device the page should be rendered to
        """
        ...


__all__ = ['RenderOptions']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from .font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.style.VerticalAlignment import VerticalAlignmentProto  # type: ignore

class UnoControlButtonModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a UnoControlButton.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UnoControlButtonModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlButtonModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlButtonModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Align(self) -> int:
        """
        specifies the horizontal alignment of the text in the control.
        """
        ...

    @abstractproperty
    def BackgroundColor(self) -> Color_68e908c5:
        """
        specifies the background color (RGB) of the control.
        """
        ...

    @abstractproperty
    def DefaultButton(self) -> bool:
        """
        specifies that the button is the default button on the document.
        """
        ...

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
        ...

    @abstractproperty
    def FocusOnClick(self) -> bool:
        """
        specifies whether the button control should grab the focus when clicked.
        
        If set to TRUE (which is the default), the button control automatically grabs the focus when the user clicks onto it with the mouse.If set to FALSE, the focus is preserved when the user operates the button control with the mouse.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def FontDescriptor(self) -> FontDescriptor_bc110c0a:
        """
        specifies the font attributes of the text in the control.
        """
        ...

    @abstractproperty
    def FontEmphasisMark(self) -> int:
        """
        specifies the com.sun.star.text.FontEmphasis value of the text in the control.
        """
        ...

    @abstractproperty
    def FontRelief(self) -> int:
        """
        specifies the com.sun.star.text.FontRelief value of the text in the control.
        """
        ...

    @abstractproperty
    def Graphic(self) -> XGraphic_a4da0afc:
        """
        specifies a graphic to be displayed at the button
        
        If this property is present, it interacts with the ImageURL in the following way:
        
        **since**
        
            OOo 2.1
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def ImageAlign(self) -> int:
        """
        specifies the alignment of the image inside the button as ImageAlign value.
        """
        ...

    @abstractproperty
    def ImagePosition(self) -> int:
        """
        specifies the position of the image, if any, relative to the text, if any
        
        Valid values of this property are specified with ImagePosition.
        
        If this property is present, it supersedes the ImageAlign property - setting one of both properties sets the other one to the best possible match.
        """
        ...

    @abstractproperty
    def ImageURL(self) -> str:
        """
        specifies a URL to an image to use for the button.
        """
        ...

    @abstractproperty
    def Label(self) -> str:
        """
        specifies the label of the control.
        """
        ...

    @abstractproperty
    def MultiLine(self) -> bool:
        """
        specifies that the text may be displayed on more than one line.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        specifies that the control will be printed with the document.
        """
        ...

    @abstractproperty
    def PushButtonType(self) -> int:
        """
        specifies the default action of the button as PushButtonType value.
        """
        ...

    @abstractproperty
    def Repeat(self) -> bool:
        """
        specifies whether the control should show repeating behavior.
        
        Normally, when you click a button with the mouse, you need to release the mouse button, and press it again. With this property set to TRUE, the button is repeatedly pressed while you hold down the mouse button.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def RepeatDelay(self) -> int:
        """
        specifies the mouse repeat delay, in milliseconds.
        
        When the user presses a mouse in a control area where this triggers an action (such as pressing the button), then usual control implementations allow to repeatedly trigger this action, without the need to release the mouse button and to press it again. The delay between two such triggers is specified with this property.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def State(self) -> int:
        """
        specifies the state of the control.
        
        If Toggle property is set to TRUE, the pressed state is enabled and its pressed state can be obtained with this property.
        """
        ...

    @abstractproperty
    def Tabstop(self) -> bool:
        """
        specifies that the control can be reached with the TAB key.
        """
        ...

    @abstractproperty
    def TextColor(self) -> Color_68e908c5:
        """
        specifies the text color (RGB) of the control.
        """
        ...

    @abstractproperty
    def TextLineColor(self) -> Color_68e908c5:
        """
        specifies the text line color (RGB) of the control.
        """
        ...

    @abstractproperty
    def Toggle(self) -> bool:
        """
        specifies whether the button should toggle on a single operation.
        
        If this property is set to TRUE, a single operation of the button control (pressing space while it is focused, or clicking onto it) toggles it between a pressed and a not pressed state.
        
        The default for this property is FALSE, which means the button behaves like a usual push button.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def VerticalAlign(self) -> VerticalAlignmentProto:
        """
        specifies the vertical alignment of the text in the control.
        
        **since**
        
            OOo 2.0
        """
        ...


__all__ = ['UnoControlButtonModel']